## Summary

<!-- Brief description of what this PR does -->

## Changes

-

## Checklist

- [ ] Tests pass (`uv run pytest`)
- [ ] Linting passes (`uv run ruff check src/ tests/`)
- [ ] Formatting passes (`uv run ruff format --check src/ tests/`)
- [ ] Type checking passes (`uv run mypy src/`)
